#!/bin/bash -e

# 服务器地址
api_server="board.bianbu.xyz:5000"

# 获取机器ID
get_machine_id() {
    # 尝试读取设备的序列号
    if cat /proc/device-tree/serial-number 2>/dev/null; then
        :
    else
        # 如果失败，错误消息
        echo "Error: Failed to retrieve machine ID." 1>&2
    fi
}

# 获取IP地址
get_ip() {
    # 查找第一个非本地回环网络接口的IPv4地址
    local active_interface=$(ip -4 route ls | grep default | grep -Po '(?<=dev )(\S+)' | head -1)
    if [[ -z "$active_interface" ]]; then
        echo "Error: No active network interface found." 1>&2
    fi

    local ip_address=$(ip addr show "$active_interface" | grep 'inet ' | awk '{print $2}' | cut -d/ -f1)
    if [[ -z "$ip_address" ]]; then
        echo "Error: No IP address found for interface  $active_interface." 1>&2
    fi
    echo "$ip_address"
}

# 上传机器信息
upload_machine_info() {
    local machine_id=$1
    local ip=$2
    local kubelet_status=$(systemctl status kubelet | grep "Active:")

    # 替换为实际的API URL
    local api_url="http://$api_server/ping"

    # 构建JSON数据
    json_payload=$(
        cat <<EOF
{
"machine_id": "$machine_id",
"ip": "$ip",
"kubelet_status": "$kubelet_status"
}
EOF
    )

    response=$(curl -s -X POST "$api_url" \
        -H "Content-Type: application/json" \
        -d "$json_payload")
    # 使用 jq 解析 JSON 响应并提取主机名
    result=$(echo $response | jq -r '.success')
}

# 获取机器ID和IP
machine_id=$(get_machine_id | tr -d '\0')
ip=$(get_ip)

# 检查机器ID和IP是否为空，如果为空，则打印错误信息并退出脚本
if [ -z "$machine_id" ] || [ -z "$ip" ]; then
    echo "Error: machine_id or ip is empty. Skip auto register node."
    exit 0
fi

# 上传信息
upload_machine_info "$machine_id" "$ip"
